@@ -1,5 +1,5 @@
 use anyhow::{Context, Result};
-use crossterm::event::{Event, EventStream};
+use crossterm::event::{Event, EventStream, KeyEventKind};
 use ratatui::{backend::Backend, Terminal};
 
 use crate::app::{App, UIComponents};
@@ -21,6 +21,7 @@ pub enum HandleInputReturnType {
     Handled,
     NotFound,
     ExitApp,
+    Ignore,
 }
 
 pub async fn run<B: Backend>(
@@ -81,6 +82,9 @@ where
             ui_components.show_err_msg(err.to_string());
         }
     }
+
+    app.load_state(&mut ui_components);
+
     if let Err(err) = app.load_entries().await {
         ui_components.show_err_msg(err.to_string());
     }
@@ -91,15 +95,28 @@ where
 
     let mut input_stream = EventStream::new();
     while let Some(event) = input_stream.next().await {
-        let event = event.context("Error gettig input stream")?;
+        let event = event.context("Error getting input stream")?;
         match handle_input(event, &mut app, &mut ui_components).await {
             Ok(result) => {
                 match result {
-                    HandleInputReturnType::Handled | HandleInputReturnType::NotFound => {
+                    HandleInputReturnType::Handled => {
                         ui_components.update_current_entry(&mut app);
                         draw_ui(terminal, &mut app, &mut ui_components)?;
                     }
-                    HandleInputReturnType::ExitApp => return Ok(()),
+                    HandleInputReturnType::NotFound => {
+                        // UI should be drawn even if the input isn't handled in the app logic to
+                        // catch events like resize, Font resize, Mouse activation...
+                        draw_ui(terminal, &mut app, &mut ui_components)?;
+                    }
+                    HandleInputReturnType::ExitApp => {
+                        // Logging persisting errors by closing the app is enough
+                        if let Err(err) = app.persist_state() {
+                            log::error!("Persisting app state failed: Error info {err}");
+                        }
+
+                        return Ok(());
+                    }
+                    HandleInputReturnType::Ignore => {}
                 };
             }
             Err(err) => {
@@ -118,11 +135,15 @@ async fn exec_pending_cmd<B: Backend, D: DataProvider>(
     pending_cmd: PendingCliCommand,
 ) -> anyhow::Result<()> {
     match pending_cmd {
-        PendingCliCommand::ImportJorunals(file_path) => {
+        PendingCliCommand::ImportJournals(file_path) => {
             terminal.draw(|f| render_message_centered(f, "Importing journals..."))?;
 
             app.import_entries(file_path).await?;
         }
+        PendingCliCommand::AssignPriority(priority) => {
+            terminal.draw(|f| render_message_centered(f, "Assigning Priority to Journals..."))?;
+            app.assign_priority_to_entries(priority).await?;
+        }
     }
 
     Ok(())
@@ -152,9 +173,13 @@ async fn handle_input<'a, D: DataProvider>(
     ui_components: &mut UIComponents<'a>,
 ) -> Result<HandleInputReturnType> {
     if let Event::Key(key) = event {
-        let input = Input::from(&key);
-
-        ui_components.handle_input(&input, app).await
+        match key.kind {
+            KeyEventKind::Press => {
+                let input = Input::from(&key);
+                ui_components.handle_input(&input, app).await
+            }
+            KeyEventKind::Repeat | KeyEventKind::Release => Ok(HandleInputReturnType::Ignore),
+        }
     } else {
         Ok(HandleInputReturnType::NotFound)
     }
