@@ -10,14 +10,16 @@ use ratatui::{
 use tui_textarea::{CursorMove, TextArea};
 
 use crate::app::{
-    filter::{CriteriaRelation, Filter, FilterCritrion},
+    filter::{CriteriaRelation, Filter, FilterCriterion},
     keymap::Input,
 };
 
-use super::ui_functions::centered_rect;
+use super::{ui_functions::centered_rect, PopupReturn, INVALID_CONTROL_COLOR};
+
+type FilterPopupReturn = PopupReturn<Option<Filter>>;
 
 const FOOTER_TEXT: &str = r"Tab: Change focused control | Enter or <Ctrl-m>: Confirm | Esc or <Ctrl-c>: Cancel | <Ctrl-r>: Change Matching Logic | <Space>: Tags Toggle Selected";
-const FOOTER_MARGINE: usize = 8;
+const FOOTER_MARGIN: usize = 8;
 const ACTIVE_BORDER_COLOR: Color = Color::LightYellow;
 
 pub struct FilterPopup<'a> {
@@ -28,21 +30,18 @@ pub struct FilterPopup<'a> {
     selected_tags: HashSet<String>,
     title_txt: TextArea<'a>,
     content_txt: TextArea<'a>,
+    priority_txt: TextArea<'a>,
+    priority_err_msg: String,
 }
 
 #[derive(Debug, PartialEq, Eq)]
 enum FilterControl {
     TitleTxt,
     ContentTxt,
+    PriorityTxt,
     TagsList,
 }
 
-pub enum FilterPopupReturn {
-    KeepPopup,
-    Cancel,
-    Apply(Option<Filter>),
-}
-
 impl<'a> FilterPopup<'a> {
     pub fn new(tags: Vec<String>, filter: Option<Filter>) -> Self {
         let filter = filter.unwrap_or_default();
@@ -52,13 +51,15 @@ impl<'a> FilterPopup<'a> {
         let mut selected_tags = HashSet::new();
         let mut title_text = String::default();
         let mut content_text = String::default();
+        let mut priority_text = String::default();
 
-        filter.critria.into_iter().for_each(|cr| match cr {
-            FilterCritrion::Tag(tag) => {
+        filter.criteria.into_iter().for_each(|cr| match cr {
+            FilterCriterion::Tag(tag) => {
                 selected_tags.insert(tag);
             }
-            FilterCritrion::Title(title_search) => title_text = title_search,
-            FilterCritrion::Content(content_search) => content_text = content_search,
+            FilterCriterion::Title(title_search) => title_text = title_search,
+            FilterCriterion::Content(content_search) => content_text = content_search,
+            FilterCriterion::Priority(prio) => priority_text = prio.to_string(),
         });
 
         let mut title_txt = TextArea::new(vec![title_text]);
@@ -67,6 +68,9 @@ impl<'a> FilterPopup<'a> {
         let mut content_txt = TextArea::new(vec![content_text]);
         content_txt.move_cursor(CursorMove::End);
 
+        let mut priority_txt = TextArea::new(vec![priority_text]);
+        priority_txt.move_cursor(CursorMove::End);
+
         let active_control = FilterControl::TitleTxt;
 
         let mut filter_popup = FilterPopup {
@@ -77,10 +81,14 @@ impl<'a> FilterPopup<'a> {
             selected_tags,
             title_txt,
             content_txt,
+            priority_txt,
+            priority_err_msg: String::default(),
         };
 
         filter_popup.cycle_next_tag();
 
+        filter_popup.validate_priority();
+
         filter_popup
     }
 
@@ -91,7 +99,7 @@ impl<'a> FilterPopup<'a> {
         frame.render_widget(Clear, area);
         frame.render_widget(block, area);
 
-        let footer_height = textwrap::fill(FOOTER_TEXT, (area.width as usize) - FOOTER_MARGINE)
+        let footer_height = textwrap::fill(FOOTER_TEXT, (area.width as usize) - FOOTER_MARGIN)
             .lines()
             .count();
 
@@ -104,6 +112,7 @@ impl<'a> FilterPopup<'a> {
                     Constraint::Length(3),
                     Constraint::Length(3),
                     Constraint::Length(3),
+                    Constraint::Length(3),
                     Constraint::Min(4),
                     Constraint::Length(footer_height.try_into().unwrap()),
                 ]
@@ -113,18 +122,17 @@ impl<'a> FilterPopup<'a> {
 
         self.render_relations(frame, chunks[0]);
 
-        self.render_text_boxes(frame, chunks[1], chunks[2]);
+        self.render_text_boxes(frame, chunks[1], chunks[2], chunks[3]);
 
         if self.tags.is_empty() {
-            self.render_tags_place_holder(frame, chunks[3]);
+            self.render_tags_place_holder(frame, chunks[4]);
         } else {
-            self.render_tags_list(frame, chunks[3]);
+            self.render_tags_list(frame, chunks[4]);
         }
 
-        self.render_footer(frame, chunks[4]);
+        self.render_footer(frame, chunks[5]);
     }
 
-    #[inline]
     fn render_relations(&mut self, frame: &mut Frame, area: Rect) {
         let relation_text = match self.relation {
             CriteriaRelation::And => "Journals must meet all criteria",
@@ -143,43 +151,73 @@ impl<'a> FilterPopup<'a> {
         frame.render_widget(relation, area);
     }
 
-    #[inline]
-    fn render_text_boxes(&mut self, frame: &mut Frame, title_area: Rect, content_area: Rect) {
+    fn render_text_boxes(
+        &mut self,
+        frame: &mut Frame,
+        title_area: Rect,
+        content_area: Rect,
+        priority_area: Rect,
+    ) {
         let active_cursor_style = Style::default().bg(ACTIVE_BORDER_COLOR).fg(Color::Black);
+        let invalid_cursor_style = Style::default().bg(INVALID_CONTROL_COLOR).fg(Color::Black);
         let deactivate_cursor_style = Style::default().bg(Color::Reset);
 
         let mut title_txt_block = Block::default().title("Title").borders(Borders::ALL);
         let mut content_txt_block = Block::default().title("Content").borders(Borders::ALL);
+        let mut priority_txt_block = if self.priority_err_msg.is_empty() {
+            Block::default().title("Priority").borders(Borders::ALL)
+        } else {
+            Block::default()
+                .title(format!("Priority : {}", self.priority_err_msg))
+                .borders(Borders::ALL)
+                .style(Style::default().fg(INVALID_CONTROL_COLOR))
+        };
 
         match self.active_control {
             FilterControl::TitleTxt => {
                 self.title_txt.set_cursor_style(active_cursor_style);
                 self.content_txt.set_cursor_style(deactivate_cursor_style);
+                self.priority_txt.set_cursor_style(deactivate_cursor_style);
                 title_txt_block = title_txt_block.style(Style::default().fg(ACTIVE_BORDER_COLOR));
             }
             FilterControl::ContentTxt => {
                 self.title_txt.set_cursor_style(deactivate_cursor_style);
                 self.content_txt.set_cursor_style(active_cursor_style);
+                self.priority_txt.set_cursor_style(deactivate_cursor_style);
                 content_txt_block =
                     content_txt_block.style(Style::default().fg(ACTIVE_BORDER_COLOR));
             }
             FilterControl::TagsList => {
                 self.title_txt.set_cursor_style(deactivate_cursor_style);
                 self.content_txt.set_cursor_style(deactivate_cursor_style);
+                self.priority_txt.set_cursor_style(deactivate_cursor_style);
+            }
+            FilterControl::PriorityTxt => {
+                self.title_txt.set_cursor_style(deactivate_cursor_style);
+                self.content_txt.set_cursor_style(deactivate_cursor_style);
+                if self.priority_err_msg.is_empty() {
+                    self.priority_txt.set_cursor_style(active_cursor_style);
+                    priority_txt_block =
+                        priority_txt_block.style(Style::default().fg(ACTIVE_BORDER_COLOR));
+                } else {
+                    self.priority_txt.set_cursor_style(invalid_cursor_style);
+                }
             }
         }
 
         self.title_txt.set_cursor_line_style(Style::default());
         self.content_txt.set_cursor_line_style(Style::default());
+        self.priority_txt.set_cursor_line_style(Style::default());
 
         self.title_txt.set_block(title_txt_block);
         self.content_txt.set_block(content_txt_block);
+        self.priority_txt.set_block(priority_txt_block);
 
         frame.render_widget(self.title_txt.widget(), title_area);
         frame.render_widget(self.content_txt.widget(), content_area);
+        frame.render_widget(self.priority_txt.widget(), priority_area);
     }
 
-    #[inline]
     fn render_tags_list(&mut self, frame: &mut Frame, area: Rect) {
         let items: Vec<ListItem> = self
             .tags
@@ -210,7 +248,6 @@ impl<'a> FilterPopup<'a> {
         frame.render_stateful_widget(list, area, &mut self.tags_state);
     }
 
-    #[inline]
     fn render_tags_place_holder(&mut self, frame: &mut Frame, area: Rect) {
         let place_holder_text = String::from("\nNo journals with tags provided");
 
@@ -222,7 +259,6 @@ impl<'a> FilterPopup<'a> {
         frame.render_widget(place_holder, area);
     }
 
-    #[inline]
     fn get_list_block<'b>(&self) -> Block<'b> {
         let style = match self.active_control {
             FilterControl::TagsList => Style::default().fg(ACTIVE_BORDER_COLOR),
@@ -235,7 +271,6 @@ impl<'a> FilterPopup<'a> {
             .style(style)
     }
 
-    #[inline]
     fn render_footer(&mut self, frame: &mut Frame, area: Rect) {
         let footer = Paragraph::new(FOOTER_TEXT)
             .alignment(Alignment::Center)
@@ -265,8 +300,15 @@ impl<'a> FilterPopup<'a> {
                 }
                 _ => {
                     match self.active_control {
-                        FilterControl::TitleTxt => self.title_txt.input(KeyEvent::from(input)),
-                        FilterControl::ContentTxt => self.content_txt.input(KeyEvent::from(input)),
+                        FilterControl::TitleTxt => _ = self.title_txt.input(KeyEvent::from(input)),
+                        FilterControl::ContentTxt => {
+                            _ = self.content_txt.input(KeyEvent::from(input))
+                        }
+                        FilterControl::PriorityTxt => {
+                            if self.priority_txt.input(KeyEvent::from(input)) {
+                                self.validate_priority();
+                            }
+                        }
                         FilterControl::TagsList => unreachable!("Tags List is unreachable here"),
                     };
                     FilterPopupReturn::KeepPopup
@@ -303,14 +345,14 @@ impl<'a> FilterPopup<'a> {
     fn cycle_next_control(&mut self) -> FilterPopupReturn {
         self.active_control = match self.active_control {
             FilterControl::TitleTxt => FilterControl::ContentTxt,
-            FilterControl::ContentTxt => FilterControl::TagsList,
+            FilterControl::ContentTxt => FilterControl::PriorityTxt,
+            FilterControl::PriorityTxt => FilterControl::TagsList,
             FilterControl::TagsList => FilterControl::TitleTxt,
         };
 
         FilterPopupReturn::KeepPopup
     }
 
-    #[inline]
     fn cycle_next_tag(&mut self) {
         if self.tags.is_empty() {
             return;
@@ -326,7 +368,6 @@ impl<'a> FilterPopup<'a> {
         self.tags_state.select(Some(new_index));
     }
 
-    #[inline]
     fn cycle_prev_tag(&mut self) {
         if self.tags.is_empty() {
             return;
@@ -342,7 +383,6 @@ impl<'a> FilterPopup<'a> {
         self.tags_state.select(Some(new_index));
     }
 
-    #[inline]
     fn change_relation(&mut self) {
         self.relation = match self.relation {
             CriteriaRelation::And => CriteriaRelation::Or,
@@ -350,7 +390,6 @@ impl<'a> FilterPopup<'a> {
         }
     }
 
-    #[inline]
     fn toggle_selected(&mut self) {
         if let Some(idx) = self.tags_state.selected() {
             let tag = self
@@ -366,11 +405,29 @@ impl<'a> FilterPopup<'a> {
         }
     }
 
-    fn confirm(&self) -> FilterPopupReturn {
+    fn validate_priority(&mut self) {
+        let prio_text = self.priority_txt.lines().first().unwrap();
+        if !prio_text.is_empty() && prio_text.parse::<u32>().is_err() {
+            self.priority_err_msg = String::from("Priority must be a positive number");
+        } else {
+            self.priority_err_msg.clear();
+        }
+    }
+
+    fn is_valid_input(&self) -> bool {
+        self.priority_err_msg.is_empty()
+    }
+
+    fn confirm(&mut self) -> FilterPopupReturn {
+        self.validate_priority();
+        if !self.is_valid_input() {
+            return FilterPopupReturn::KeepPopup;
+        }
+
         let mut critria: Vec<_> = self
             .selected_tags
             .iter()
-            .map(|tag| FilterCritrion::Tag(tag.into()))
+            .map(|tag| FilterCriterion::Tag(tag.into()))
             .collect();
 
         let title_filter = self
@@ -380,7 +437,7 @@ impl<'a> FilterPopup<'a> {
             .expect("Title TextBox has one line");
 
         if !title_filter.is_empty() {
-            critria.push(FilterCritrion::Title(title_filter.to_owned()));
+            critria.push(FilterCriterion::Title(title_filter.to_owned()));
         }
 
         let content_filter = self
@@ -390,7 +447,19 @@ impl<'a> FilterPopup<'a> {
             .expect("Content TextBox has one line");
 
         if !content_filter.is_empty() {
-            critria.push(FilterCritrion::Content(content_filter.to_owned()));
+            critria.push(FilterCriterion::Content(content_filter.to_owned()));
+        }
+
+        let priority_filter = self
+            .priority_txt
+            .lines()
+            .first()
+            .expect("Priority text box has one line");
+        if !priority_filter.is_empty() {
+            let prio = priority_filter
+                .parse()
+                .expect("Priority text is validated at this point");
+            critria.push(FilterCriterion::Priority(prio));
         }
 
         if critria.is_empty() {
@@ -398,7 +467,7 @@ impl<'a> FilterPopup<'a> {
         } else {
             let filter = Filter {
                 relation: self.relation,
-                critria,
+                criteria: critria,
             };
 
             FilterPopupReturn::Apply(Some(filter))
